@@ -20,6 +20,8 @@ function _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps(p) {
         _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType(p.responseTypes);
     visitedObjects.delete(p);
 }
+function _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer(p) {
+}
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer(p) {
 }
 function _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer(p) {
@@ -43,5 +45,5 @@ function print(name, deprecationMessage) {
 const visitedObjects = new Set();
 class DeprecationError extends Error {
 }
-module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer };
+module.exports = { print, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaResponseType, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizerProps, _aws_cdk_aws_apigatewayv2_authorizers_HttpIamAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpJwtAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpUserPoolAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_HttpLambdaAuthorizer, _aws_cdk_aws_apigatewayv2_authorizers_WebSocketLambdaAuthorizer };
 module.exports.DeprecationError = DeprecationError;
